unit FileNamePropEdit;
{-----------------------------------------------------------------------------}
{ Name        : FileNamePropEdit                                              }
{ Application : TFileNamePropEdit Property Editor                             }
{ Version     : 1.00                                                          }
{ Author      : Orlando Arrocha           email: oarrocha@hotmail.com         }
{ Date        : Jul 2001                                                      }
{ Purpose     : This property editor lets you browse for files on design time }
{               when field type is TFileName.                                 }
{ ---------                                                                   }
{  TERMS                                                                      }
{ ---------                                                                   }
{   This property editor is provided AS-IS without any warranty of any kind,  }
{   either express or implied. This component is freeware and can be used in  }
{   any software product.                                                     }
{ ----------------                                                            }
{  How to Install                                                             }
{ ----------------                                                            }
{   1. Copy this file to the folder from where you wish to install the        }
{      property editor. This will probably be a sub-folder of the             }
{      $(DELPHI)\lib folder.                                                  }
{   2. Install the property editor by choosing the                            }
{      Component | Install Component menu option.                             }
{      The following instructions assume you are installing into the default  }
{      "users components" package:                                            }
{   3. Select the "Into existing package" page of the Install Components     }
{      dialogue box.                                                          }
{   4. Browse to the folder where you saved this file and select it.          }
{   5. Ensure that the "Package file name" edit box contains                  }
{      $(DELPHI)\lib\dclusr??.dpk (where ?? should be 30, 40, 50 depending of }
{      Delphi's version).                                                     }
{   6. Accept that the package will be rebuilt.                               }
{                                                                             }
{-----------------------------------------------------------------------------}

interface
uses
  DsgnIntf, Classes, Forms, SysUtils, Dialogs;

type
  TFileNamePropEdit = class(TStringProperty)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
  end;

procedure Register;

implementation

procedure TFileNamePropEdit.Edit;
var
  OpenDialog : TOpenDialog;
begin
  OpenDialog := TOpenDialog.Create(Application);
  try
    OpenDialog.Filename := GetValue;
    OpenDialog.Options := OpenDialog.Options + [ofPathMustExist];
    if OpenDialog.Execute then
      SetValue(OpenDialog.Filename);
  finally
    OpenDialog.Free;
  end;
end;

function TFileNamePropEdit.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog, paRevertable];
end;

procedure Register;
begin
  RegisterPropertyEditor(TypeInfo(TFileName), nil, '', TFileNamePropEdit);
end;

end.
